minimumBoardHeight property
Minimum height class required before the board can switch to columns.
Implementation
final AdaptiveHeight minimumBoardHeight;
Minimum height class required before the board can switch to columns.
final AdaptiveHeight minimumBoardHeight;