AdaptiveBoardLane class

A single lane definition used by AdaptiveBoard.

Constructors

AdaptiveBoardLane({required String title, required List<Widget> items, String? description, Widget? leading, Widget? trailing, Widget? footer, Widget? emptyState})
Creates a lane definition.
const

Properties

description String?
Optional supporting copy shown below the title.
final
emptyState Widget?
Optional empty state shown when items is empty.
final
Optional footer shown after the lane items.
final
hashCode int
The hash code for this object.
no setterinherited
items List<Widget>
Items shown inside the lane body.
final
leading Widget?
Optional leading widget shown in the lane header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Lane title shown in the lane header.
final
trailing Widget?
Optional trailing widget shown in the lane header.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited