minimumSplitHeight property
Minimum height class required before editor and preview can split.
Implementation
final AdaptiveHeight minimumSplitHeight;
Minimum height class required before editor and preview can split.
final AdaptiveHeight minimumSplitHeight;