minimumInsightsDockedHeight property
Minimum height class required before the insights panel can dock inline.
Implementation
final AdaptiveHeight minimumInsightsDockedHeight;
Minimum height class required before the insights panel can dock inline.
final AdaptiveHeight minimumInsightsDockedHeight;