minimumSidebarDockedHeight property
Minimum height class required before the sidebar can dock inline.
Implementation
final AdaptiveHeight minimumSidebarDockedHeight;
Minimum height class required before the sidebar can dock inline.
final AdaptiveHeight minimumSidebarDockedHeight;