minimumGridHeight property
Minimum height class required before the view can switch to grid mode.
Implementation
final AdaptiveHeight minimumGridHeight;
Minimum height class required before the view can switch to grid mode.
final AdaptiveHeight minimumGridHeight;