minimumExperimentDockedHeight property
Minimum height class required before the experiment list can dock inline.
Implementation
final AdaptiveHeight minimumExperimentDockedHeight;
Minimum height class required before the experiment list can dock inline.
final AdaptiveHeight minimumExperimentDockedHeight;