AdaptiveGalleryItem class

A single entry shown by AdaptiveGallery.

Constructors

AdaptiveGalleryItem({required String label, required Widget preview, required Widget child, String? description, Widget? leading, Widget? trailing, Widget? thumbnail, Widget? footer, String? tooltip})
Creates a gallery item definition.
const

Properties

child Widget
Supporting details shown below preview.
final
description String?
Optional supporting copy shown below label.
final
Optional footer shown below child.
final
hashCode int
The hash code for this object.
no setterinherited
label String
Label shown in the card header and selector list.
final
leading Widget?
Optional leading widget shown in the selector row.
final
preview Widget
Main visual preview shown by the gallery card.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail Widget?
Optional compact visual used by the selector list.
final
tooltip String?
Optional tooltip used by compact indicators and selector rows.
final
trailing Widget?
Optional trailing widget shown in the card header and selector row.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited