contextBuilder property
Builds the supporting context panel for the selected incident.
Implementation
final Widget Function(BuildContext context, T incident) contextBuilder;
Builds the supporting context panel for the selected incident.
final Widget Function(BuildContext context, T incident) contextBuilder;