detailBuilder property
Builds the active incident detail for the selected incident.
Implementation
final Widget Function(BuildContext context, T incident) detailBuilder;
Builds the active incident detail for the selected incident.
final Widget Function(BuildContext context, T incident) detailBuilder;