minimumTimelineDockedHeight property
Minimum height class required before the timeline panel can dock inline.
Implementation
final AdaptiveHeight minimumTimelineDockedHeight;
Minimum height class required before the timeline panel can dock inline.
final AdaptiveHeight minimumTimelineDockedHeight;