timelineBuilder property
Builds the timeline or activity panel for the selected incident.
Implementation
final Widget Function(BuildContext context, T incident) timelineBuilder;
Builds the timeline or activity panel for the selected incident.
final Widget Function(BuildContext context, T incident) timelineBuilder;