annotationsDockedAt property
Semantic size at which the annotations panel should dock inline.
Implementation
final AdaptiveSize annotationsDockedAt;
Semantic size at which the annotations panel should dock inline.
final AdaptiveSize annotationsDockedAt;