historyBuilder property
Builds the query history panel for the selected query.
Implementation
final Widget Function(BuildContext context, T query) historyBuilder;
Builds the query history panel for the selected query.
final Widget Function(BuildContext context, T query) historyBuilder;