focusBuilder property
Builds the active plan focus surface for the selected plan.
Implementation
final Widget Function(BuildContext context, T plan) focusBuilder;
Builds the active plan focus surface for the selected plan.
final Widget Function(BuildContext context, T plan) focusBuilder;