milestonesDockedAt property
Semantic size at which the milestones panel should dock inline.
Implementation
final AdaptiveSize milestonesDockedAt;
Semantic size at which the milestones panel should dock inline.
final AdaptiveSize milestonesDockedAt;