minimumNotesDockedHeight property
Minimum height class required before the notes surface can dock inline.
Implementation
final AdaptiveHeight minimumNotesDockedHeight;
Minimum height class required before the notes surface can dock inline.
final AdaptiveHeight minimumNotesDockedHeight;