readinessBuilder property
Builds the active readiness surface for the selected release.
Implementation
final Widget Function(BuildContext context, T release) readinessBuilder;
Builds the active readiness surface for the selected release.
final Widget Function(BuildContext context, T release) readinessBuilder;