minimumColumnsHeight property
Minimum height class required before the view can switch to column mode.
Implementation
final AdaptiveHeight minimumColumnsHeight;
Minimum height class required before the view can switch to column mode.
final AdaptiveHeight minimumColumnsHeight;