AdaptiveScheduleDay class

A day or lane within AdaptiveSchedule.

Constructors

AdaptiveScheduleDay({required String label, required List<AdaptiveScheduleEntry> entries, String? description, Widget? leading, Widget? trailing, Widget? footer, Widget? emptyState})
Creates a schedule day definition.
const

Properties

description String?
Optional supporting copy shown below label.
final
emptyState Widget?
Optional empty state shown when entries is empty.
final
entries List<AdaptiveScheduleEntry>
Scheduled items for this day.
final
Optional footer shown below all entries.
final
hashCode int
The hash code for this object.
no setterinherited
label String
Day label shown in the day header.
final
leading Widget?
Optional leading widget shown in the day header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing Widget?
Optional trailing widget shown in the day header.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited