minimumHorizontalHeight property
Minimum height class required before the horizontal mode is allowed.
Implementation
final AdaptiveHeight minimumHorizontalHeight;
Minimum height class required before the horizontal mode is allowed.
final AdaptiveHeight minimumHorizontalHeight;