minimumLibraryDockedHeight property
Minimum height class required before the library can dock inline.
Implementation
final AdaptiveHeight minimumLibraryDockedHeight;
Minimum height class required before the library can dock inline.
final AdaptiveHeight minimumLibraryDockedHeight;