AdaptiveBoard class
A workflow board that stacks lanes on compact widths and becomes a board on larger containers.
Compact containers render lanes vertically. Medium and expanded containers render horizontally scrollable columns.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AdaptiveBoard
Constructors
-
AdaptiveBoard({Key? key, required List<
AdaptiveBoardLane> lanes, AdaptiveSize boardAt = AdaptiveSize.medium, AdaptiveHeight minimumBoardHeight = AdaptiveHeight.compact, bool useContainerConstraints = true, bool considerOrientation = false, double laneWidth = 280, double laneSpacing = 16, double itemSpacing = 12, EdgeInsetsGeometry lanePadding = const EdgeInsets.all(16), bool animateTransitions = true, Duration transitionDuration = const Duration(milliseconds: 250), Curve transitionCurve = Curves.easeInOutCubic}) -
Creates an adaptive board.
const
Properties
- animateTransitions → bool
-
Whether transitions should animate.
final
- boardAt → AdaptiveSize
-
Semantic size at which the board should switch to column mode.
final
- considerOrientation → bool
-
Whether orientation should influence container-based breakpoint selection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemSpacing → double
-
Space between items inside a lane.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lanePadding → EdgeInsetsGeometry
-
Padding applied inside each lane surface.
final
-
lanes
→ List<
AdaptiveBoardLane> -
Lanes shown by the board.
final
- laneSpacing → double
-
Space between adjacent lanes.
final
- laneWidth → double
-
Width of each board lane in column mode.
final
- minimumBoardHeight → AdaptiveHeight
-
Minimum height class required before the board can switch to columns.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionCurve → Curve
-
Curve used by animations.
final
- transitionDuration → Duration
-
Duration used by animations.
final
- useContainerConstraints → bool
-
Whether to derive layout mode from parent constraints.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited