AdaptiveCalendar class
A calendar surface that shows a stacked agenda on compact layouts and a multi-column day grid on larger containers.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AdaptiveCalendar
Constructors
-
AdaptiveCalendar({Key? key, required List<
AdaptiveCalendarDay> days, AdaptiveSize gridAt = AdaptiveSize.medium, AdaptiveHeight minimumGridHeight = AdaptiveHeight.compact, bool useContainerConstraints = true, bool considerOrientation = false, int gridColumns = 7, double minDayWidth = 170, double daySpacing = 12, double entrySpacing = 10, EdgeInsetsGeometry dayPadding = const EdgeInsets.all(14), bool animateTransitions = true, Duration transitionDuration = const Duration(milliseconds: 250), Curve transitionCurve = Curves.easeInOutCubic}) -
Creates an adaptive calendar.
const
Properties
- animateTransitions → bool
-
Whether transitions should animate.
final
- considerOrientation → bool
-
Whether orientation should influence container-based breakpoint selection.
final
- dayPadding → EdgeInsetsGeometry
-
Padding applied inside each day surface.
final
-
days
→ List<
AdaptiveCalendarDay> -
Days shown by the calendar.
final
- daySpacing → double
-
Space between days.
final
- entrySpacing → double
-
Space between entries inside a day.
final
- gridAt → AdaptiveSize
-
Semantic size at which the view should switch to grid mode.
final
- gridColumns → int
-
Number of day columns shown in grid mode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minDayWidth → double
-
Minimum width used by each grid day.
final
- minimumGridHeight → AdaptiveHeight
-
Minimum height class required before the view can switch to grid mode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionCurve → Curve
-
Curve used by animations.
final
- transitionDuration → Duration
-
Duration used by animations.
final
- useContainerConstraints → bool
-
Whether to derive the active mode from parent constraints.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited