AdaptiveCalendarDay class
A single day shown by AdaptiveCalendar.
Constructors
Properties
- emptyState → Widget?
-
Optional empty state shown when entries is empty.
final
-
entries
→ List<
Widget> -
Events or blocks shown inside the day.
final
-
Optional footer shown below the entries.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight → bool
-
Whether the day should be visually emphasized.
final
- label → String
-
Day label shown in the day header.
final
- leading → Widget?
-
Optional leading widget shown in the day header.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional supporting copy shown below label.
final
- trailing → Widget?
-
Optional trailing widget shown in the day header.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited