AdaptiveComparisonItem class
A single option or variant shown by AdaptiveComparison.
Constructors
Properties
- child → Widget
-
Main content shown inside the card.
final
- description → String?
-
Optional supporting description shown below the label.
final
-
Optional footer shown below child.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Label shown in the compact selector and the card header.
final
- leading → Widget?
-
Optional leading widget shown in the selector and card header.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → String?
-
Optional tooltip used by the compact selector.
final
- trailing → Widget?
-
Optional trailing widget shown in the card header.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited