AdaptiveSchedule class
A day-grouped schedule that shows a stacked agenda on compact layouts and side-by-side day columns on larger containers.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AdaptiveSchedule
Constructors
-
AdaptiveSchedule({Key? key, required List<
AdaptiveScheduleDay> days, AdaptiveSize columnsAt = AdaptiveSize.medium, AdaptiveHeight minimumColumnsHeight = AdaptiveHeight.compact, bool useContainerConstraints = true, bool considerOrientation = false, double dayWidth = 300, double daySpacing = 16, double entrySpacing = 12, EdgeInsetsGeometry dayPadding = const EdgeInsets.all(16), bool animateTransitions = true, Duration transitionDuration = const Duration(milliseconds: 250), Curve transitionCurve = Curves.easeInOutCubic}) -
Creates an adaptive schedule.
const
Properties
- animateTransitions → bool
-
Whether transitions should animate.
final
- columnsAt → AdaptiveSize
-
Semantic size at which the view should switch to column mode.
final
- considerOrientation → bool
-
Whether orientation should influence container-based breakpoint selection.
final
- dayPadding → EdgeInsetsGeometry
-
Padding applied inside each day surface.
final
-
days
→ List<
AdaptiveScheduleDay> -
Days shown by the schedule.
final
- daySpacing → double
-
Space between adjacent day surfaces.
final
- dayWidth → double
-
Width of each day column in wide mode.
final
- entrySpacing → double
-
Space between adjacent entries inside a day.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minimumColumnsHeight → AdaptiveHeight
-
Minimum height class required before the view can switch to column mode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionCurve → Curve
-
Curve used by animations.
final
- transitionDuration → Duration
-
Duration used by animations.
final
- useContainerConstraints → bool
-
Whether to derive the active mode from parent constraints.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited