AdaptiveScheduleEntry class
A single scheduled item shown inside an AdaptiveScheduleDay.
Constructors
Properties
- child → Widget?
-
Optional custom content shown below the copy.
final
- description → String?
-
Optional supporting copy shown below title.
final
-
Optional footer shown below child.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leading → Widget?
-
Optional leading widget shown with the entry.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeLabel → String
-
Time label shown beside or above the entry content.
final
- title → String
-
Entry title.
final
- trailing → Widget?
-
Optional trailing widget shown with the entry.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited