AdaptiveTimeline class
A milestone timeline that stacks on compact widths and becomes horizontal on larger containers.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AdaptiveTimeline
Constructors
-
AdaptiveTimeline({Key? key, required List<
AdaptiveTimelineEntry> entries, AdaptiveSize horizontalAt = AdaptiveSize.medium, AdaptiveHeight minimumHorizontalHeight = AdaptiveHeight.compact, bool useContainerConstraints = true, bool considerOrientation = false, double entryWidth = 260, double entrySpacing = 20, EdgeInsetsGeometry cardPadding = const EdgeInsets.all(16), bool animateTransitions = true, Duration transitionDuration = const Duration(milliseconds: 250), Curve transitionCurve = Curves.easeInOutCubic}) -
Creates an adaptive timeline.
const
Properties
- animateTransitions → bool
-
Whether transitions should animate.
final
- cardPadding → EdgeInsetsGeometry
-
Padding applied inside each milestone card.
final
- considerOrientation → bool
-
Whether orientation should affect container-based breakpoint resolution.
final
-
entries
→ List<
AdaptiveTimelineEntry> -
Timeline entries shown by the widget.
final
- entrySpacing → double
-
Space between entries.
final
- entryWidth → double
-
Width used by entries in horizontal mode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalAt → AdaptiveSize
-
Semantic size at which the timeline should switch to horizontal mode.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minimumHorizontalHeight → AdaptiveHeight
-
Minimum height class required before the horizontal mode is allowed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionCurve → Curve
-
Curve used by animations.
final
- transitionDuration → Duration
-
Duration used by animations.
final
- useContainerConstraints → bool
-
Whether to derive the active mode from parent constraints.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited