AdaptiveTimelineEntry class
A single milestone definition used by AdaptiveTimeline.
Constructors
Properties
- child → Widget?
-
Optional custom content shown below the copy.
final
- description → String?
-
Optional supporting copy shown under title.
final
-
Optional footer shown below the milestone body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
Optional short label shown above the milestone title.
final
- leading → Widget?
-
Optional leading widget shown near the milestone marker.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Milestone title.
final
- trailing → Widget?
-
Optional trailing widget shown in the milestone card.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited